==> jc-1.4.0.tar.gz: javax/security/auth/login/AccountExpiredException.h <==
// public class javax.security.auth.login.AccountExpiredException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class ba608b7080f4bd1d javax_security_auth_login_AccountExpiredException
// @dep_class 41e228596abd0321 javax_security_auth_login_LoginException

// header file dependencies
// @dep_header javax_security_auth_login_LoginException

#include "javax/security/auth/login/LoginException.h"

#ifndef _JC_javax_security_auth_login_AccountExpiredException_H_
#define _JC_javax_security_auth_login_AccountExpiredException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_AccountExpiredException$sub_refs	_jc_javax_security_auth_login_AccountExpiredException$sub_refs;
typedef struct _jc_javax_security_auth_login_AccountExpiredException$sub_nonrefs	_jc_javax_security_auth_login_AccountExpiredException$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_AccountExpiredException$refs	_jc_javax_security_auth_login_AccountExpiredException$refs;
typedef struct _jc_javax_security_auth_login_AccountExpiredException$nonrefs	_jc_javax_security_auth_login_AccountExpiredException$nonrefs;
typedef struct _jc_javax_security_auth_login_AccountExpiredException$object	_jc_javax_security_auth_login_AccountExpiredException$object;

typedef struct _jc_javax_security_auth_login_AccountExpiredException$fields_struct	_jc_javax_security_auth_login_AccountExpiredException$fields_struct;
typedef const struct _jc_javax_security_auth_login_AccountExpiredException$vmethods	_jc_javax_security_auth_login_AccountExpiredException$vmethods;
typedef const struct _jc_javax_security_auth_login_AccountExpiredException$vtable	_jc_javax_security_auth_login_AccountExpiredException$vtable;
typedef const struct _jc_javax_security_auth_login_AccountExpiredException$vtype	_jc_javax_security_auth_login_AccountExpiredException$vtype;

// Class fields structure
struct _jc_javax_security_auth_login_AccountExpiredException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_security_auth_login_AccountExpiredException$fields_struct _jc_javax_security_auth_login_AccountExpiredException$class_fields;

// Constructors
extern void _jc_javax_security_auth_login_AccountExpiredException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_login_AccountExpiredException$object *);
extern void _jc_javax_security_auth_login_AccountExpiredException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_login_AccountExpiredException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_security_auth_login_AccountExpiredException$vmethods {
};

// Vtable
struct _jc_javax_security_auth_login_AccountExpiredException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_javax_security_auth_login_LoginException$vmethods	javax_security_auth_login_LoginException;
	_jc_javax_security_auth_login_AccountExpiredException$vmethods	javax_security_auth_login_AccountExpiredException;
};

// Vtype
struct _jc_javax_security_auth_login_AccountExpiredException$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_AccountExpiredException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_AccountExpiredException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_AccountExpiredException$refs {
    _jc_javax_security_auth_login_AccountExpiredException$sub_refs	javax_security_auth_login_AccountExpiredException;
    _jc_javax_security_auth_login_LoginException$sub_refs	javax_security_auth_login_LoginException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_AccountExpiredException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_AccountExpiredException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_javax_security_auth_login_LoginException$sub_nonrefs	javax_security_auth_login_LoginException;
    _jc_javax_security_auth_login_AccountExpiredException$sub_nonrefs	javax_security_auth_login_AccountExpiredException;
};

// Object instance structure
struct _jc_javax_security_auth_login_AccountExpiredException$object {
	_jc_javax_security_auth_login_AccountExpiredException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_AccountExpiredException$vtype	*vtype;
	_jc_javax_security_auth_login_AccountExpiredException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_AccountExpiredException$vtype _jc_javax_security_auth_login_AccountExpiredException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_AccountExpiredException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_AccountExpiredException$class_object;

#endif	/* _JC_javax_security_auth_login_AccountExpiredException_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/login/AccountExpiredException.h <==
// public class javax.security.auth.login.AccountExpiredException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class ba608b7080f4bd1d javax_security_auth_login_AccountExpiredException
// @dep_class 41e228596abd0321 javax_security_auth_login_LoginException

// header file dependencies
// @dep_header javax_security_auth_login_LoginException

#include "javax/security/auth/login/LoginException.h"

#ifndef _JC_javax_security_auth_login_AccountExpiredException_H_
#define _JC_javax_security_auth_login_AccountExpiredException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_AccountExpiredException$sub_refs	_jc_javax_security_auth_login_AccountExpiredException$sub_refs;
typedef struct _jc_javax_security_auth_login_AccountExpiredException$sub_nonrefs	_jc_javax_security_auth_login_AccountExpiredException$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_AccountExpiredException$refs	_jc_javax_security_auth_login_AccountExpiredException$refs;
typedef struct _jc_javax_security_auth_login_AccountExpiredException$nonrefs	_jc_javax_security_auth_login_AccountExpiredException$nonrefs;
typedef struct _jc_javax_security_auth_login_AccountExpiredException$object	_jc_javax_security_auth_login_AccountExpiredException$object;

typedef struct _jc_javax_security_auth_login_AccountExpiredException$fields_struct	_jc_javax_security_auth_login_AccountExpiredException$fields_struct;
typedef const struct _jc_javax_security_auth_login_AccountExpiredException$vmethods	_jc_javax_security_auth_login_AccountExpiredException$vmethods;
typedef const struct _jc_javax_security_auth_login_AccountExpiredException$vtable	_jc_javax_security_auth_login_AccountExpiredException$vtable;
typedef const struct _jc_javax_security_auth_login_AccountExpiredException$vtype	_jc_javax_security_auth_login_AccountExpiredException$vtype;

// Class fields structure
struct _jc_javax_security_auth_login_AccountExpiredException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_security_auth_login_AccountExpiredException$fields_struct _jc_javax_security_auth_login_AccountExpiredException$class_fields;

// Constructors
extern void _jc_javax_security_auth_login_AccountExpiredException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_login_AccountExpiredException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_AccountExpiredException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_login_AccountExpiredException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_auth_login_AccountExpiredException$vmethods {
};

// Vtable
struct _jc_javax_security_auth_login_AccountExpiredException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_javax_security_auth_login_LoginException$vmethods	javax_security_auth_login_LoginException;
	_jc_javax_security_auth_login_AccountExpiredException$vmethods	javax_security_auth_login_AccountExpiredException;
};

// Vtype
struct _jc_javax_security_auth_login_AccountExpiredException$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_AccountExpiredException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_AccountExpiredException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_AccountExpiredException$refs {
    _jc_javax_security_auth_login_AccountExpiredException$sub_refs	javax_security_auth_login_AccountExpiredException;
    _jc_javax_security_auth_login_LoginException$sub_refs	javax_security_auth_login_LoginException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_AccountExpiredException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_AccountExpiredException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_javax_security_auth_login_LoginException$sub_nonrefs	javax_security_auth_login_LoginException;
    _jc_javax_security_auth_login_AccountExpiredException$sub_nonrefs	javax_security_auth_login_AccountExpiredException;
};

// Object instance structure
struct _jc_javax_security_auth_login_AccountExpiredException$object {
	_jc_javax_security_auth_login_AccountExpiredException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_AccountExpiredException$vtype	*vtype;
	_jc_javax_security_auth_login_AccountExpiredException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_AccountExpiredException$vtype _jc_javax_security_auth_login_AccountExpiredException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_AccountExpiredException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_AccountExpiredException$class_object;

#endif	/* _JC_javax_security_auth_login_AccountExpiredException_H_ */
